@@ -9,7 +9,7 @@ Class, Function
 __copyright__ = 'Copyright (C) 2021 @koKkekoh'
 __license__ = 'BSD 2-Clause License'
 __author__  = '@koKekkoh'
-__version__ = '0.26.1' # 2021-11-02
+__version__ = '0.27.0' # 2021-11-04
 __url__     = 'https://qiita.com/tags/sphinxcotrib.kana_text'
 
 import re, pathlib
@@ -172,6 +172,7 @@ class KanaText(nodes.Node):
             option_marker = _dflt_option_marker
 
         self._rawword = rawword
+        self._rawtext = rawtext
         self._delimiter = _chop.sub('', separator)
         self._separator = separator
         self._option_marker = option_marker
@@ -212,7 +213,7 @@ class KanaText(nodes.Node):
             else:
                 raise KeyError(key)
         else:
-            raise KeyError(key)
+            raise TypeError(key)
 
     def __eq__(self, other):
         """unittest用"""
@@ -249,6 +250,8 @@ class KanaText(nodes.Node):
             return f"<{name}: len={len(self)} <#text: '{hier}'>>"
         elif self._rawword:
             return f"<{name}: <#rawword: '{self._rawword}'>>"
+        elif self._rawtext:
+            return f"<#rawtext: '{self._rawtext}'>"
         else:
             return "<#empty>"
 
@@ -305,7 +308,7 @@ class KanaText(nodes.Node):
             '田中はな子'
         """
         if len(self) < 1:
-            raise ValueError(self._rawword, len(self), self[0], self[1], self)
+            raise ValueError(self._rawword, repr(self))
 
         return self[0]
 
@@ -328,13 +331,11 @@ class KanaText(nodes.Node):
         ruby, option = self['ruby'], self['option']
 
         if len(self) < 1:
-            raw = self.rawsource
-            name = self.__class__.__name__
-            raise ValueError(f"{name}('{raw}')", self.children)
+            raise ValueError(self._rawword, repr(self))
         elif len(self) == 1:
             hier = self[0]
             if hier: data = [(False, hier)]
-            else   : data = None
+            else   : raise ValueError(self._rawword, repr(self))
         elif not ruby:
             hier = self[0]
             data = [(False, hier), ]
@@ -424,7 +425,7 @@ class ExIndexEntry(idxr.IndexEntry):
             rubys.append(child.asruby())
         return rubys
 
-    def ashtml(self, concat=('; ', 3)):
+    def ashtml(self, concat=(', ', 3)):
         html = concat[0].join(h.ashtml() for h in self)
         return html
 
@@ -534,7 +535,7 @@ class ExIndexRack(idxr.IndexRack):
             entry.packclass = ExSubterm
             index_units = entry.make_index_units()
             for iu in index_units:
-                self.put_in_kana_catalog(iu['main'], iu.get_children())
+                self.put_in_kana_catalog(iu['main'], iu.get_terms())
 
         # 設定ファイルで用意されたかな文字情報の登録
         for rawword in get_word_list_from_file(builder.config):
@@ -543,7 +544,7 @@ class ExIndexRack(idxr.IndexRack):
             entry.packclass = ExSubterm
             index_units = entry.make_index_units()
             for iu in index_units:
-                self.put_in_kana_catalog(iu['main'], iu.get_children())
+                self.put_in_kana_catalog(iu['main'], iu.get_terms())
 
         super().__init__(builder)
 
@@ -569,7 +570,7 @@ class ExIndexRack(idxr.IndexRack):
         - 全unitを見て決める更新処理のための情報収集
         """
         # 情報収集
-        self.put_in_kana_catalog(unit['main'], unit.get_children())
+        self.put_in_kana_catalog(unit['main'], unit.get_terms())
         unit[self.UNIT_TERM].kana_text_on_genindex = self.config.kana_text_on_genindex
 
         # 残りの処理
@@ -632,7 +633,7 @@ class ExIndexRack(idxr.IndexRack):
 
             self.update_term_with_kana_catalog(unit[self.UNIT_TERM])
 
-            for subterm in unit[self.UNIT_SBTM]._terms:
+            for subterm in unit[self.UNIT_SBTM]:
                 self.update_term_with_kana_catalog(subterm)
 
             # kana_text_change_tripleの設定値を反映
@@ -664,29 +665,33 @@ class ExSubterm(idxr.Subterm):
         return nodes.unescape(self.ashier())
 
     def astext(self):
-        if self._template and len(self) == 1:
-            return self._template % self._terms[0].ashier()
+        if self['template'] and len(self) == 1:
+            return self['template'] % self[0].ashier()
 
         text = ""
-        for subterm in self._terms:
-            text += subterm.astext() + self._delimiter
-        return text[:-len(self._delimiter)]
+        for subterm in self:
+            text += subterm.astext() + self['delimiter']
+        return text[:-len(self['delimiter'])]
 
     def ashier(self):
-        if self._template and len(self) == 1:
-            return self._template % self._terms[0].ashier()
+        if self['template'] and len(self) == 1:
+            return self['template'] % self[0].ashier()
 
-        if self.change_triple and len(self) == 2 and self._delimiter == ', ':
-            return self._terms[1].ashier() + self._delimiter + self._terms[0].ashier()
+        if self.change_triple and len(self) == 2 and self['delimiter'] == ', ':
+            return self[1].ashier() + self['delimiter'] + self[0].ashier()
 
         hier = ""
-        for subterm in self._terms:
-            hier += subterm.ashier() + self._delimiter
-        return hier[:-len(self._delimiter)]
+        for subterm in self:
+            hier += subterm.ashier() + self['delimiter']
+        return hier[:-len(self['delimiter'])]
 
 
 class ExIndexUnit(idxr.IndexUnit):
-    pass
+    def get_terms(self):
+        terms = [self[1]]
+        for s in self[2]:
+            terms.append(s)
+        return terms
 
 
 # ------------------------------------------------------------
@@ -806,6 +811,6 @@ def setup(app) -> Dict[str, Any]:
 # ------------------------------------------------------------
 
 
-if __name__ == '__main__':
+if __name__ in ('__main__', 'src'):
     import doctest
     doctest.testmod()
